@@ -4,16 +4,17 @@ cibere.dev python wrapper
 A basic wrapper cibere.dev
 
 .. include:: ../extras/index_page.md
+.. include:: ../extras/update-log.md
 """
 
 __description__ = "A basic wrapper cibere.dev"
-__version__ = "0.4.1"
+__version__ = "0.4.2"
 
 from typing import Literal, NamedTuple
 
 from .client import Client
 from .errors import *
-from .screenshot import Screenshot
+from .file import File
 from .searching import SearchResult
 
 
