@@ -1,21 +1,82 @@
 __all__ = [
-    "ClientNotStarted",
+    "ClientAlreadyClosed",
     "UnknownError",
     "InvalidURL",
     "UnableToConnect",
     "APIOffline",
+    "UnknownDataReturned",
+    "APIException",
+    "UnknownStatusCode",
 ]
 
 
-class BaseError(Exception):
+class CiberedevException(Exception):
     pass
 
 
-class APIError(BaseError):
+class ScreenshotException(CiberedevException):
     pass
 
 
-class APIOffline(APIError):
+class APIException(CiberedevException):
+    def __init__(self, error: str):
+        """Creates an APIException error stinace
+
+        This is raised when the api returns an error
+        It is not recommended to raise this yourself
+
+        """
+
+        super().__init__(error)
+
+
+class UnknownStatusCode(APIException):
+    def __init__(self, code: int):
+        """Creates an UnknownStatusCode error stinace
+
+        This is raised when the api returns an unknown status code
+        It is not recommended to raise this yourself
+
+        Parameters
+        ----------
+        code: `int`
+            the status code that was returned
+
+        Attributes
+        ----------
+        code: `int`
+            the status code that was returned
+        """
+
+        self.code = code
+        super().__init__(f"API returned an unknown status code: '{self.code}'")
+
+
+class UnknownDataReturned(APIException):
+    def __init__(self, endpoint: str):
+        """Creates an UnknownDataReturned error stinace
+
+        This is raised when the data the api returns does not match what the client believes it should return
+        It is not recommended to raise this yourself
+
+        Parameters
+        ----------
+        endpoint: `str`
+            The endpoint the client is making a request to when this happend
+
+        Attributes
+        ----------
+        endpoint: `str`
+            The endpoint the client is making a request to when this happend
+        """
+
+        self.endpoint = endpoint
+        super().__init__(
+            f"API returned unknown data when making a request to '{endpoint}'"
+        )
+
+
+class APIOffline(APIException):
     def __init__(self, endpoint: str):
         """Creates an APIOffline error instance.
 
@@ -37,9 +98,9 @@ class APIOffline(APIError):
         super().__init__(f"API is down. Aborting API request to '{endpoint}'")
 
 
-class ClientNotStarted(BaseError):
+class ClientAlreadyClosed(APIException):
     def __init__(self):
-        """Creates a ClientNotStarted error instance.
+        """Creates a ClientAlreadyClosed error instance.
 
         It is not recommended to raise this yourself
         """
@@ -49,17 +110,7 @@ class ClientNotStarted(BaseError):
         )
 
 
-class ClientAlreadyStarted(BaseError):
-    def __init__(self):
-        """Creates a ClientAlreadyStarted error instance.
-
-        It is not recommended to raise this yourself
-        """
-
-        super().__init__("Client has already been started")
-
-
-class UnknownError(BaseError):
+class UnknownError(CiberedevException):
     def __init__(self, error: str):
         """Creates a UnknownError error instance.
 
@@ -80,11 +131,7 @@ class UnknownError(BaseError):
         super().__init__(f"An unknown error has occured: {error}")
 
 
-class ScreenshotError(BaseError):
-    pass
-
-
-class InvalidURL(ScreenshotError):
+class InvalidURL(ScreenshotException):
     def __init__(self, url: str):
         """Creates a InvalidURL error instance.
 
@@ -105,7 +152,7 @@ class InvalidURL(ScreenshotError):
         super().__init__(f"Invalid URL Given: '{self.url}'")
 
 
-class UnableToConnect(ScreenshotError):
+class UnableToConnect(ScreenshotException):
     def __init__(self, url: str):
         """Creates a UnableToConnect error instance.
 
